@@ -48,7 +48,7 @@ class GmailClient(EmailClient):
                     sender = gmail_quote.span.a.get_text()
                 elif len(gmail_quote) < 10:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.contents[1:])
-                    date = None
+                    date = datetime.datetime.strptime(gmail_quote.contents[0].contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                     sender = gmail_quote.span.a.get_text()                
                 else:
                     body = ''.join(str(tag).strip() for tag in gmail_quote.div.contents)
